@@ -1,14 +1,12 @@
 import numpy as np
-import tensorflow as tf
 import json
 
-AA_COUNT = 20
 AA_DICT = {'A': 0, 'C': 1, 'D': 2, 'E': 3, 'F': 4,
            'G': 5, 'H': 6, 'I': 7, 'K': 8, 'L': 9,
            'M': 10, 'N': 11, 'P': 12, 'Q': 13, 'R': 14,
            'S': 15, 'T': 16, 'V': 17, 'W': 18, 'Y': 19,
            '?': 20}
-
+AA_COUNT = len(AA_DICT)
 AA_DICT_REV = {AA_DICT[key]: key for key in AA_DICT}
 
 
@@ -110,8 +108,6 @@ class CipherAminoAcidDs(object):
         x = self.encrypt(x, selected_ciphers)
         y = selected_ciphers
         x, _ = self.mask_data(x, mask_prob)
-        x = tf.one_hot(x, len(AA_DICT))
-        y = tf.one_hot(y, self.n_of_ciphers)
 
         return x, y
 
